@@ -8,7 +8,7 @@ using namespace Rcpp;
 
 
 // [[Rcpp::export(".r_g_vMF_Cpp")]]
-arma::mat r_g_vMF_Cpp(arma::uword n, arma::uword p, double kappa) {
+arma::vec r_g_vMF_Cpp(arma::uword n, arma::uword p, double kappa) {
 
   // Algorithm VM in Wood (1994)
 
@@ -49,7 +49,7 @@ arma::mat r_g_vMF_Cpp(arma::uword n, arma::uword p, double kappa) {
   }
 
   // Sample
-  return(std::move(W));
+  return(W);
 
 }
 
